Tests for two groups comparison — STAC 0.7 documentation

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »

# Tests for two groups comparison

`ttest_ind`(a, b[, axis, equal_var]) | Calculates the T-test for the means of TWO INDEPENDENT samples of scores.
`ttest_rel`(a, b[, axis]) | Calculates the T-test on TWO RELATED samples of scores, a and b.
`wilcoxon`(x[, y, zero_method, correction]) | Calculate the Wilcoxon signed-rank test.
`mannwhitneyu`(x, y[, use_continuity]) | Computes the Mann-Whitney rank test on samples x and y.

`binomial_sign_test`(*args) | Performs a binomial sign test for two dependent samples.

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »